@@ -5,13 +5,13 @@
 #  LinuxDoc-Tools driver core. This contains all the basic
 #  functionality we need to control all other components.
 #
-#  Copyright  1996, Cees de Groot.
-#  Copyright  2000, Taketoshi Sano
-#  Copyright  2006-2020, Agustin Martin
+#  Copyright (C) 1996, Cees de Groot.
+#  Copyright (C) 2000, Taketoshi Sano
+#  Copyright (C) 2006-2020, Agustin Martin
 # -------------------------------------------------------------------
 package LinuxDocTools;
 
-require 5.006;
+use 5.006;
 use strict;
 use LinuxDocTools::Data::Latin1ToSgml qw{ldt_latin1tosgml};
 
@@ -198,19 +198,21 @@ sub init {
 			  { option => "tabsize",   type => "i", short => "t" },
 			  # { option => "verbose",   type => "f", short => "v" },
 			  { option => "debug",     type => "f", short => "d" },
+			  { option => "rtldirection",     type => "f", short => "r" },
 			  { option => "define",    type => "s", short => "D" },
 			  { option => "include",   type => "s", short => "i" },
 			  { option => "pass",      type => "s", short => "P" }
 			  ];
   $global->{backend}   = "linuxdoc";
   $global->{papersize} = "a4";
-  $global->{language}  = "en";
+  $global->{language}  = '';
   $global->{charset}   = "ascii";
   $global->{style}     = "";
   $global->{tabsize}   = 8;
   $global->{verbose}   = 0;
   $global->{define}    = "";
   $global->{debug}     = 0;
+  $global->{rtldirection}     = 0;
   $global->{include}   = "";
   $global->{logfile}   = '';
   $global->{pass}      = "";
@@ -344,7 +346,8 @@ sub process_options {
   $#files > -1 || usage("No filenames given");
 
   # Normalize language string
-  $global->{language} = Any2ISO($global->{language});
+  $global->{language} = Any2ISO($global->{language})
+    if ( defined $global->{language} );
 
   # Fine tune japanese and korean charsets when not utf-8
   if ($global->{charset} ne "utf-8") {
